//go:build !disable_pgv
// Code generated by protoc-gen-validate. DO NOT EDIT.
// source: envoy/config/filter/http/cache/v2alpha/cache.proto

package v2alpha

import (
	"bytes"
	"errors"
	"fmt"
	"net"
	"net/mail"
	"net/url"
	"regexp"
	"sort"
	"strings"
	"time"
	"unicode/utf8"

	"google.golang.org/protobuf/types/known/anypb"
)

// ensure the imports are used
var (
	_ = bytes.MinRead
	_ = errors.New("")
	_ = fmt.Print
	_ = utf8.UTFMax
	_ = (*regexp.Regexp)(nil)
	_ = (*strings.Reader)(nil)
	_ = net.IPv4len
	_ = time.Duration(0)
	_ = (*url.URL)(nil)
	_ = (*mail.Address)(nil)
	_ = anypb.Any{}
	_ = sort.Sort
)

// Validate checks the field values on CacheConfig with the rules defined in
// the proto definition for this message. If any rules are violated, the first
// error encountered is returned, or nil if there are no violations.
func (m *CacheConfig) Validate() error {
	return m.validate(false)
}

// ValidateAll checks the field values on CacheConfig with the rules defined in
// the proto definition for this message. If any rules are violated, the
// result is a list of violation errors wrapped in CacheConfigMultiError, or
// nil if none found.
func (m *CacheConfig) ValidateAll() error {
	return m.validate(true)
}

func (m *CacheConfig) validate(all bool) error {
	if m == nil {
		return nil
	}

	var errors []error

	if m.GetTypedConfig() == nil {
		err := CacheConfigValidationError{
			field:  "TypedConfig",
			reason: "value is required",
		}
		if !all {
			return err
		}
		errors = append(errors, err)
	}

	if a := m.GetTypedConfig(); a != nil {

	}

	for idx, item := range m.GetAllowedVaryHeaders() {
		_, _ = idx, item

		if all {
			switch v := interface{}(item).(type) {
			case interface{ ValidateAll() error }:
				if err := v.ValidateAll(); err != nil {
					errors = append(errors, CacheConfigValidationError{
						field:  fmt.Sprintf("AllowedVaryHeaders[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			case interface{ Validate() error }:
				if err := v.Validate(); err != nil {
					errors = append(errors, CacheConfigValidationError{
						field:  fmt.Sprintf("AllowedVaryHeaders[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			}
		} else if v, ok := interface{}(item).(interface{ Validate() error }); ok {
			if err := v.Validate(); err != nil {
				return CacheConfigValidationError{
					field:  fmt.Sprintf("AllowedVaryHeaders[%v]", idx),
					reason: "embedded message failed validation",
					cause:  err,
				}
			}
		}

	}

	if all {
		switch v := interface{}(m.GetKeyCreatorParams()).(type) {
		case interface{ ValidateAll() error }:
			if err := v.ValidateAll(); err != nil {
				errors = append(errors, CacheConfigValidationError{
					field:  "KeyCreatorParams",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		case interface{ Validate() error }:
			if err := v.Validate(); err != nil {
				errors = append(errors, CacheConfigValidationError{
					field:  "KeyCreatorParams",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		}
	} else if v, ok := interface{}(m.GetKeyCreatorParams()).(interface{ Validate() error }); ok {
		if err := v.Validate(); err != nil {
			return CacheConfigValidationError{
				field:  "KeyCreatorParams",
				reason: "embedded message failed validation",
				cause:  err,
			}
		}
	}

	// no validation rules for MaxBodyBytes

	if len(errors) > 0 {
		return CacheConfigMultiError(errors)
	}

	return nil
}

// CacheConfigMultiError is an error wrapping multiple validation errors
// returned by CacheConfig.ValidateAll() if the designated constraints aren't met.
type CacheConfigMultiError []error

// Error returns a concatenation of all the error messages it wraps.
func (m CacheConfigMultiError) Error() string {
	var msgs []string
	for _, err := range m {
		msgs = append(msgs, err.Error())
	}
	return strings.Join(msgs, "; ")
}

// AllErrors returns a list of validation violation errors.
func (m CacheConfigMultiError) AllErrors() []error { return m }

// CacheConfigValidationError is the validation error returned by
// CacheConfig.Validate if the designated constraints aren't met.
type CacheConfigValidationError struct {
	field  string
	reason string
	cause  error
	key    bool
}

// Field function returns field value.
func (e CacheConfigValidationError) Field() string { return e.field }

// Reason function returns reason value.
func (e CacheConfigValidationError) Reason() string { return e.reason }

// Cause function returns cause value.
func (e CacheConfigValidationError) Cause() error { return e.cause }

// Key function returns key value.
func (e CacheConfigValidationError) Key() bool { return e.key }

// ErrorName returns error name.
func (e CacheConfigValidationError) ErrorName() string { return "CacheConfigValidationError" }

// Error satisfies the builtin error interface
func (e CacheConfigValidationError) Error() string {
	cause := ""
	if e.cause != nil {
		cause = fmt.Sprintf(" | caused by: %v", e.cause)
	}

	key := ""
	if e.key {
		key = "key for "
	}

	return fmt.Sprintf(
		"invalid %sCacheConfig.%s: %s%s",
		key,
		e.field,
		e.reason,
		cause)
}

var _ error = CacheConfigValidationError{}

var _ interface {
	Field() string
	Reason() string
	Key() bool
	Cause() error
	ErrorName() string
} = CacheConfigValidationError{}

// Validate checks the field values on CacheConfig_KeyCreatorParams with the
// rules defined in the proto definition for this message. If any rules are
// violated, the first error encountered is returned, or nil if there are no violations.
func (m *CacheConfig_KeyCreatorParams) Validate() error {
	return m.validate(false)
}

// ValidateAll checks the field values on CacheConfig_KeyCreatorParams with the
// rules defined in the proto definition for this message. If any rules are
// violated, the result is a list of violation errors wrapped in
// CacheConfig_KeyCreatorParamsMultiError, or nil if none found.
func (m *CacheConfig_KeyCreatorParams) ValidateAll() error {
	return m.validate(true)
}

func (m *CacheConfig_KeyCreatorParams) validate(all bool) error {
	if m == nil {
		return nil
	}

	var errors []error

	// no validation rules for ExcludeScheme

	// no validation rules for ExcludeHost

	for idx, item := range m.GetQueryParametersIncluded() {
		_, _ = idx, item

		if all {
			switch v := interface{}(item).(type) {
			case interface{ ValidateAll() error }:
				if err := v.ValidateAll(); err != nil {
					errors = append(errors, CacheConfig_KeyCreatorParamsValidationError{
						field:  fmt.Sprintf("QueryParametersIncluded[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			case interface{ Validate() error }:
				if err := v.Validate(); err != nil {
					errors = append(errors, CacheConfig_KeyCreatorParamsValidationError{
						field:  fmt.Sprintf("QueryParametersIncluded[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			}
		} else if v, ok := interface{}(item).(interface{ Validate() error }); ok {
			if err := v.Validate(); err != nil {
				return CacheConfig_KeyCreatorParamsValidationError{
					field:  fmt.Sprintf("QueryParametersIncluded[%v]", idx),
					reason: "embedded message failed validation",
					cause:  err,
				}
			}
		}

	}

	for idx, item := range m.GetQueryParametersExcluded() {
		_, _ = idx, item

		if all {
			switch v := interface{}(item).(type) {
			case interface{ ValidateAll() error }:
				if err := v.ValidateAll(); err != nil {
					errors = append(errors, CacheConfig_KeyCreatorParamsValidationError{
						field:  fmt.Sprintf("QueryParametersExcluded[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			case interface{ Validate() error }:
				if err := v.Validate(); err != nil {
					errors = append(errors, CacheConfig_KeyCreatorParamsValidationError{
						field:  fmt.Sprintf("QueryParametersExcluded[%v]", idx),
						reason: "embedded message failed validation",
						cause:  err,
					})
				}
			}
		} else if v, ok := interface{}(item).(interface{ Validate() error }); ok {
			if err := v.Validate(); err != nil {
				return CacheConfig_KeyCreatorParamsValidationError{
					field:  fmt.Sprintf("QueryParametersExcluded[%v]", idx),
					reason: "embedded message failed validation",
					cause:  err,
				}
			}
		}

	}

	if len(errors) > 0 {
		return CacheConfig_KeyCreatorParamsMultiError(errors)
	}

	return nil
}

// CacheConfig_KeyCreatorParamsMultiError is an error wrapping multiple
// validation errors returned by CacheConfig_KeyCreatorParams.ValidateAll() if
// the designated constraints aren't met.
type CacheConfig_KeyCreatorParamsMultiError []error

// Error returns a concatenation of all the error messages it wraps.
func (m CacheConfig_KeyCreatorParamsMultiError) Error() string {
	var msgs []string
	for _, err := range m {
		msgs = append(msgs, err.Error())
	}
	return strings.Join(msgs, "; ")
}

// AllErrors returns a list of validation violation errors.
func (m CacheConfig_KeyCreatorParamsMultiError) AllErrors() []error { return m }

// CacheConfig_KeyCreatorParamsValidationError is the validation error returned
// by CacheConfig_KeyCreatorParams.Validate if the designated constraints
// aren't met.
type CacheConfig_KeyCreatorParamsValidationError struct {
	field  string
	reason string
	cause  error
	key    bool
}

// Field function returns field value.
func (e CacheConfig_KeyCreatorParamsValidationError) Field() string { return e.field }

// Reason function returns reason value.
func (e CacheConfig_KeyCreatorParamsValidationError) Reason() string { return e.reason }

// Cause function returns cause value.
func (e CacheConfig_KeyCreatorParamsValidationError) Cause() error { return e.cause }

// Key function returns key value.
func (e CacheConfig_KeyCreatorParamsValidationError) Key() bool { return e.key }

// ErrorName returns error name.
func (e CacheConfig_KeyCreatorParamsValidationError) ErrorName() string {
	return "CacheConfig_KeyCreatorParamsValidationError"
}

// Error satisfies the builtin error interface
func (e CacheConfig_KeyCreatorParamsValidationError) Error() string {
	cause := ""
	if e.cause != nil {
		cause = fmt.Sprintf(" | caused by: %v", e.cause)
	}

	key := ""
	if e.key {
		key = "key for "
	}

	return fmt.Sprintf(
		"invalid %sCacheConfig_KeyCreatorParams.%s: %s%s",
		key,
		e.field,
		e.reason,
		cause)
}

var _ error = CacheConfig_KeyCreatorParamsValidationError{}

var _ interface {
	Field() string
	Reason() string
	Key() bool
	Cause() error
	ErrorName() string
} = CacheConfig_KeyCreatorParamsValidationError{}
