// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.30.0
// 	protoc        v5.29.1
// source: envoy/extensions/stat_sinks/graphite_statsd/v3/graphite_statsd.proto

package graphite_statsdv3

import (
	_ "github.com/cncf/xds/go/udpa/annotations"
	v3 "github.com/envoyproxy/go-control-plane/envoy/config/core/v3"
	_ "github.com/envoyproxy/protoc-gen-validate/validate"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	wrapperspb "google.golang.org/protobuf/types/known/wrapperspb"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GraphiteStatsdSink struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// Types that are assignable to StatsdSpecifier:
	//
	//	*GraphiteStatsdSink_Address
	StatsdSpecifier isGraphiteStatsdSink_StatsdSpecifier `protobuf_oneof:"statsd_specifier"`
	// Optional custom metric name prefix. See :ref:`StatsdSink's prefix field
	// <envoy_v3_api_field_config.metrics.v3.StatsdSink.prefix>` for more details.
	Prefix string `protobuf:"bytes,3,opt,name=prefix,proto3" json:"prefix,omitempty"`
	// Optional max datagram size to use when sending UDP messages. By default Envoy
	// will emit one metric per datagram. By specifying a max-size larger than a single
	// metric, Envoy will emit multiple, new-line separated metrics. The max datagram
	// size should not exceed your network's MTU.
	//
	// Note that this value may not be respected if smaller than a single metric.
	MaxBytesPerDatagram *wrapperspb.UInt64Value `protobuf:"bytes,4,opt,name=max_bytes_per_datagram,json=maxBytesPerDatagram,proto3" json:"max_bytes_per_datagram,omitempty"`
}

func (x *GraphiteStatsdSink) Reset() {
	*x = GraphiteStatsdSink{}
	if protoimpl.UnsafeEnabled {
		mi := &file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GraphiteStatsdSink) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GraphiteStatsdSink) ProtoMessage() {}

func (x *GraphiteStatsdSink) ProtoReflect() protoreflect.Message {
	mi := &file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GraphiteStatsdSink.ProtoReflect.Descriptor instead.
func (*GraphiteStatsdSink) Descriptor() ([]byte, []int) {
	return file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescGZIP(), []int{0}
}

func (m *GraphiteStatsdSink) GetStatsdSpecifier() isGraphiteStatsdSink_StatsdSpecifier {
	if m != nil {
		return m.StatsdSpecifier
	}
	return nil
}

func (x *GraphiteStatsdSink) GetAddress() *v3.Address {
	if x, ok := x.GetStatsdSpecifier().(*GraphiteStatsdSink_Address); ok {
		return x.Address
	}
	return nil
}

func (x *GraphiteStatsdSink) GetPrefix() string {
	if x != nil {
		return x.Prefix
	}
	return ""
}

func (x *GraphiteStatsdSink) GetMaxBytesPerDatagram() *wrapperspb.UInt64Value {
	if x != nil {
		return x.MaxBytesPerDatagram
	}
	return nil
}

type isGraphiteStatsdSink_StatsdSpecifier interface {
	isGraphiteStatsdSink_StatsdSpecifier()
}

type GraphiteStatsdSink_Address struct {
	// The UDP address of a running Graphite-compliant listener. If specified,
	// statistics will be flushed to this address.
	Address *v3.Address `protobuf:"bytes,1,opt,name=address,proto3,oneof"`
}

func (*GraphiteStatsdSink_Address) isGraphiteStatsdSink_StatsdSpecifier() {}

var File_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto protoreflect.FileDescriptor

var file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDesc = []byte{
	0x0a, 0x44, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2f, 0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f,
	0x6e, 0x73, 0x2f, 0x73, 0x74, 0x61, 0x74, 0x5f, 0x73, 0x69, 0x6e, 0x6b, 0x73, 0x2f, 0x67, 0x72,
	0x61, 0x70, 0x68, 0x69, 0x74, 0x65, 0x5f, 0x73, 0x74, 0x61, 0x74, 0x73, 0x64, 0x2f, 0x76, 0x33,
	0x2f, 0x67, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74, 0x65, 0x5f, 0x73, 0x74, 0x61, 0x74, 0x73, 0x64,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x2e, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2e, 0x65, 0x78,
	0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2e, 0x73, 0x74, 0x61, 0x74, 0x5f, 0x73, 0x69,
	0x6e, 0x6b, 0x73, 0x2e, 0x67, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74, 0x65, 0x5f, 0x73, 0x74, 0x61,
	0x74, 0x73, 0x64, 0x2e, 0x76, 0x33, 0x1a, 0x22, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2f, 0x63, 0x6f,
	0x6e, 0x66, 0x69, 0x67, 0x2f, 0x63, 0x6f, 0x72, 0x65, 0x2f, 0x76, 0x33, 0x2f, 0x61, 0x64, 0x64,
	0x72, 0x65, 0x73, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x1e, 0x67, 0x6f, 0x6f, 0x67,
	0x6c, 0x65, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2f, 0x77, 0x72, 0x61, 0x70,
	0x70, 0x65, 0x72, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x1d, 0x75, 0x64, 0x70, 0x61,
	0x2f, 0x61, 0x6e, 0x6e, 0x6f, 0x74, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x73, 0x2f, 0x73, 0x74, 0x61,
	0x74, 0x75, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x17, 0x76, 0x61, 0x6c, 0x69, 0x64,
	0x61, 0x74, 0x65, 0x2f, 0x76, 0x61, 0x6c, 0x69, 0x64, 0x61, 0x74, 0x65, 0x2e, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x22, 0xdc, 0x01, 0x0a, 0x12, 0x47, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74, 0x65, 0x53,
	0x74, 0x61, 0x74, 0x73, 0x64, 0x53, 0x69, 0x6e, 0x6b, 0x12, 0x39, 0x0a, 0x07, 0x61, 0x64, 0x64,
	0x72, 0x65, 0x73, 0x73, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1d, 0x2e, 0x65, 0x6e, 0x76,
	0x6f, 0x79, 0x2e, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x2e, 0x63, 0x6f, 0x72, 0x65, 0x2e, 0x76,
	0x33, 0x2e, 0x41, 0x64, 0x64, 0x72, 0x65, 0x73, 0x73, 0x48, 0x00, 0x52, 0x07, 0x61, 0x64, 0x64,
	0x72, 0x65, 0x73, 0x73, 0x12, 0x16, 0x0a, 0x06, 0x70, 0x72, 0x65, 0x66, 0x69, 0x78, 0x18, 0x03,
	0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x70, 0x72, 0x65, 0x66, 0x69, 0x78, 0x12, 0x5a, 0x0a, 0x16,
	0x6d, 0x61, 0x78, 0x5f, 0x62, 0x79, 0x74, 0x65, 0x73, 0x5f, 0x70, 0x65, 0x72, 0x5f, 0x64, 0x61,
	0x74, 0x61, 0x67, 0x72, 0x61, 0x6d, 0x18, 0x04, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1c, 0x2e, 0x67,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x62, 0x75, 0x66, 0x2e, 0x55,
	0x49, 0x6e, 0x74, 0x36, 0x34, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x42, 0x07, 0xfa, 0x42, 0x04, 0x32,
	0x02, 0x20, 0x00, 0x52, 0x13, 0x6d, 0x61, 0x78, 0x42, 0x79, 0x74, 0x65, 0x73, 0x50, 0x65, 0x72,
	0x44, 0x61, 0x74, 0x61, 0x67, 0x72, 0x61, 0x6d, 0x42, 0x17, 0x0a, 0x10, 0x73, 0x74, 0x61, 0x74,
	0x73, 0x64, 0x5f, 0x73, 0x70, 0x65, 0x63, 0x69, 0x66, 0x69, 0x65, 0x72, 0x12, 0x03, 0xf8, 0x42,
	0x01, 0x42, 0xc6, 0x01, 0xba, 0x80, 0xc8, 0xd1, 0x06, 0x02, 0x10, 0x02, 0x0a, 0x3c, 0x69, 0x6f,
	0x2e, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x70, 0x72, 0x6f, 0x78, 0x79, 0x2e, 0x65, 0x6e, 0x76, 0x6f,
	0x79, 0x2e, 0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2e, 0x73, 0x74, 0x61,
	0x74, 0x5f, 0x73, 0x69, 0x6e, 0x6b, 0x73, 0x2e, 0x67, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74, 0x65,
	0x5f, 0x73, 0x74, 0x61, 0x74, 0x73, 0x64, 0x2e, 0x76, 0x33, 0x42, 0x13, 0x47, 0x72, 0x61, 0x70,
	0x68, 0x69, 0x74, 0x65, 0x53, 0x74, 0x61, 0x74, 0x73, 0x64, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x50,
	0x01, 0x5a, 0x67, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x65, 0x6e,
	0x76, 0x6f, 0x79, 0x70, 0x72, 0x6f, 0x78, 0x79, 0x2f, 0x67, 0x6f, 0x2d, 0x63, 0x6f, 0x6e, 0x74,
	0x72, 0x6f, 0x6c, 0x2d, 0x70, 0x6c, 0x61, 0x6e, 0x65, 0x2f, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2f,
	0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2f, 0x73, 0x74, 0x61, 0x74, 0x5f,
	0x73, 0x69, 0x6e, 0x6b, 0x73, 0x2f, 0x67, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74, 0x65, 0x5f, 0x73,
	0x74, 0x61, 0x74, 0x73, 0x64, 0x2f, 0x76, 0x33, 0x3b, 0x67, 0x72, 0x61, 0x70, 0x68, 0x69, 0x74,
	0x65, 0x5f, 0x73, 0x74, 0x61, 0x74, 0x73, 0x64, 0x76, 0x33, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x33,
}

var (
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescOnce sync.Once
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescData = file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDesc
)

func file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescGZIP() []byte {
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescOnce.Do(func() {
		file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescData = protoimpl.X.CompressGZIP(file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescData)
	})
	return file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDescData
}

var file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_goTypes = []interface{}{
	(*GraphiteStatsdSink)(nil),     // 0: envoy.extensions.stat_sinks.graphite_statsd.v3.GraphiteStatsdSink
	(*v3.Address)(nil),             // 1: envoy.config.core.v3.Address
	(*wrapperspb.UInt64Value)(nil), // 2: google.protobuf.UInt64Value
}
var file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_depIdxs = []int32{
	1, // 0: envoy.extensions.stat_sinks.graphite_statsd.v3.GraphiteStatsdSink.address:type_name -> envoy.config.core.v3.Address
	2, // 1: envoy.extensions.stat_sinks.graphite_statsd.v3.GraphiteStatsdSink.max_bytes_per_datagram:type_name -> google.protobuf.UInt64Value
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_init() }
func file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_init() {
	if File_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GraphiteStatsdSink); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes[0].OneofWrappers = []interface{}{
		(*GraphiteStatsdSink_Address)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_goTypes,
		DependencyIndexes: file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_depIdxs,
		MessageInfos:      file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_msgTypes,
	}.Build()
	File_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto = out.File
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_rawDesc = nil
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_goTypes = nil
	file_envoy_extensions_stat_sinks_graphite_statsd_v3_graphite_statsd_proto_depIdxs = nil
}
