// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.30.0
// 	protoc        v5.29.1
// source: contrib/envoy/extensions/network/connection_balance/dlb/v3alpha/dlb.proto

package v3alpha

import (
	_ "github.com/cncf/xds/go/udpa/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// The fallback policy if any error occurs.
// The default policy is None.
type Dlb_FallbackPolicy int32

const (
	// No fallback policy.
	Dlb_None Dlb_FallbackPolicy = 0
	// Fall back to Nop Connection Balance.
	Dlb_NopConnectionBalance Dlb_FallbackPolicy = 1
	// Fall back to Exact Connection Balance.
	Dlb_ExactConnectionBalance Dlb_FallbackPolicy = 2
)

// Enum value maps for Dlb_FallbackPolicy.
var (
	Dlb_FallbackPolicy_name = map[int32]string{
		0: "None",
		1: "NopConnectionBalance",
		2: "ExactConnectionBalance",
	}
	Dlb_FallbackPolicy_value = map[string]int32{
		"None":                   0,
		"NopConnectionBalance":   1,
		"ExactConnectionBalance": 2,
	}
)

func (x Dlb_FallbackPolicy) Enum() *Dlb_FallbackPolicy {
	p := new(Dlb_FallbackPolicy)
	*p = x
	return p
}

func (x Dlb_FallbackPolicy) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Dlb_FallbackPolicy) Descriptor() protoreflect.EnumDescriptor {
	return file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_enumTypes[0].Descriptor()
}

func (Dlb_FallbackPolicy) Type() protoreflect.EnumType {
	return &file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_enumTypes[0]
}

func (x Dlb_FallbackPolicy) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Dlb_FallbackPolicy.Descriptor instead.
func (Dlb_FallbackPolicy) EnumDescriptor() ([]byte, []int) {
	return file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescGZIP(), []int{0, 0}
}

// The Dlb is a hardware managed system of queues and arbiters connecting producers and consumers. It is a PCIE device
// in the CPU package. It interacts with software running on cores and potentially other devices. The Dlb implements the
// following balancing features:
//
// -  Lock-free multi-producer/multi-consumer operation.
// -  Multiple priorities for varying traffic types.
// -  Various distribution schemes.
//
// Dlb connection balancer uses Dlb hardware to balance connections, and can significantly reduce latency.
//
// As the Dlb connection balancer provides assistance from dedicated Dlb hardware, it can be used for a proxy with a large number of connections
// (e.g., a gateway).
type Dlb struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The ID of the Dlb hardware, start from 0.
	// If not specified, use the first available device as default.
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// Maximum number of retries when sending to DLB device fails.
	// No retry as default.
	MaxRetries     uint32             `protobuf:"varint,2,opt,name=max_retries,json=maxRetries,proto3" json:"max_retries,omitempty"`
	FallbackPolicy Dlb_FallbackPolicy `protobuf:"varint,3,opt,name=fallback_policy,json=fallbackPolicy,proto3,enum=envoy.extensions.network.connection_balance.dlb.v3alpha.Dlb_FallbackPolicy" json:"fallback_policy,omitempty"`
}

func (x *Dlb) Reset() {
	*x = Dlb{}
	if protoimpl.UnsafeEnabled {
		mi := &file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *Dlb) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Dlb) ProtoMessage() {}

func (x *Dlb) ProtoReflect() protoreflect.Message {
	mi := &file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Dlb.ProtoReflect.Descriptor instead.
func (*Dlb) Descriptor() ([]byte, []int) {
	return file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescGZIP(), []int{0}
}

func (x *Dlb) GetId() uint32 {
	if x != nil {
		return x.Id
	}
	return 0
}

func (x *Dlb) GetMaxRetries() uint32 {
	if x != nil {
		return x.MaxRetries
	}
	return 0
}

func (x *Dlb) GetFallbackPolicy() Dlb_FallbackPolicy {
	if x != nil {
		return x.FallbackPolicy
	}
	return Dlb_None
}

var File_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto protoreflect.FileDescriptor

var file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDesc = []byte{
	0x0a, 0x49, 0x63, 0x6f, 0x6e, 0x74, 0x72, 0x69, 0x62, 0x2f, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2f,
	0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2f, 0x6e, 0x65, 0x74, 0x77, 0x6f,
	0x72, 0x6b, 0x2f, 0x63, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x5f, 0x62, 0x61,
	0x6c, 0x61, 0x6e, 0x63, 0x65, 0x2f, 0x64, 0x6c, 0x62, 0x2f, 0x76, 0x33, 0x61, 0x6c, 0x70, 0x68,
	0x61, 0x2f, 0x64, 0x6c, 0x62, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x37, 0x65, 0x6e, 0x76,
	0x6f, 0x79, 0x2e, 0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2e, 0x6e, 0x65,
	0x74, 0x77, 0x6f, 0x72, 0x6b, 0x2e, 0x63, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e,
	0x5f, 0x62, 0x61, 0x6c, 0x61, 0x6e, 0x63, 0x65, 0x2e, 0x64, 0x6c, 0x62, 0x2e, 0x76, 0x33, 0x61,
	0x6c, 0x70, 0x68, 0x61, 0x1a, 0x1d, 0x75, 0x64, 0x70, 0x61, 0x2f, 0x61, 0x6e, 0x6e, 0x6f, 0x74,
	0x61, 0x74, 0x69, 0x6f, 0x6e, 0x73, 0x2f, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x2e, 0x70, 0x72,
	0x6f, 0x74, 0x6f, 0x22, 0xfe, 0x01, 0x0a, 0x03, 0x44, 0x6c, 0x62, 0x12, 0x0e, 0x0a, 0x02, 0x69,
	0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0d, 0x52, 0x02, 0x69, 0x64, 0x12, 0x1f, 0x0a, 0x0b, 0x6d,
	0x61, 0x78, 0x5f, 0x72, 0x65, 0x74, 0x72, 0x69, 0x65, 0x73, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0d,
	0x52, 0x0a, 0x6d, 0x61, 0x78, 0x52, 0x65, 0x74, 0x72, 0x69, 0x65, 0x73, 0x12, 0x74, 0x0a, 0x0f,
	0x66, 0x61, 0x6c, 0x6c, 0x62, 0x61, 0x63, 0x6b, 0x5f, 0x70, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x18,
	0x03, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x4b, 0x2e, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2e, 0x65, 0x78,
	0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2e, 0x6e, 0x65, 0x74, 0x77, 0x6f, 0x72, 0x6b,
	0x2e, 0x63, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x5f, 0x62, 0x61, 0x6c, 0x61,
	0x6e, 0x63, 0x65, 0x2e, 0x64, 0x6c, 0x62, 0x2e, 0x76, 0x33, 0x61, 0x6c, 0x70, 0x68, 0x61, 0x2e,
	0x44, 0x6c, 0x62, 0x2e, 0x46, 0x61, 0x6c, 0x6c, 0x62, 0x61, 0x63, 0x6b, 0x50, 0x6f, 0x6c, 0x69,
	0x63, 0x79, 0x52, 0x0e, 0x66, 0x61, 0x6c, 0x6c, 0x62, 0x61, 0x63, 0x6b, 0x50, 0x6f, 0x6c, 0x69,
	0x63, 0x79, 0x22, 0x50, 0x0a, 0x0e, 0x46, 0x61, 0x6c, 0x6c, 0x62, 0x61, 0x63, 0x6b, 0x50, 0x6f,
	0x6c, 0x69, 0x63, 0x79, 0x12, 0x08, 0x0a, 0x04, 0x4e, 0x6f, 0x6e, 0x65, 0x10, 0x00, 0x12, 0x18,
	0x0a, 0x14, 0x4e, 0x6f, 0x70, 0x43, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x42,
	0x61, 0x6c, 0x61, 0x6e, 0x63, 0x65, 0x10, 0x01, 0x12, 0x1a, 0x0a, 0x16, 0x45, 0x78, 0x61, 0x63,
	0x74, 0x43, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x42, 0x61, 0x6c, 0x61, 0x6e,
	0x63, 0x65, 0x10, 0x02, 0x42, 0xc3, 0x01, 0xba, 0x80, 0xc8, 0xd1, 0x06, 0x02, 0x10, 0x02, 0x0a,
	0x45, 0x69, 0x6f, 0x2e, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x70, 0x72, 0x6f, 0x78, 0x79, 0x2e, 0x65,
	0x6e, 0x76, 0x6f, 0x79, 0x2e, 0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x2e,
	0x6e, 0x65, 0x74, 0x77, 0x6f, 0x72, 0x6b, 0x2e, 0x63, 0x6f, 0x6e, 0x6e, 0x65, 0x63, 0x74, 0x69,
	0x6f, 0x6e, 0x5f, 0x62, 0x61, 0x6c, 0x61, 0x6e, 0x63, 0x65, 0x2e, 0x64, 0x6c, 0x62, 0x2e, 0x76,
	0x33, 0x61, 0x6c, 0x70, 0x68, 0x61, 0x42, 0x08, 0x44, 0x6c, 0x62, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x50, 0x01, 0x5a, 0x66, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x65,
	0x6e, 0x76, 0x6f, 0x79, 0x70, 0x72, 0x6f, 0x78, 0x79, 0x2f, 0x67, 0x6f, 0x2d, 0x63, 0x6f, 0x6e,
	0x74, 0x72, 0x6f, 0x6c, 0x2d, 0x70, 0x6c, 0x61, 0x6e, 0x65, 0x2f, 0x63, 0x6f, 0x6e, 0x74, 0x72,
	0x69, 0x62, 0x2f, 0x65, 0x6e, 0x76, 0x6f, 0x79, 0x2f, 0x65, 0x78, 0x74, 0x65, 0x6e, 0x73, 0x69,
	0x6f, 0x6e, 0x73, 0x2f, 0x6e, 0x65, 0x74, 0x77, 0x6f, 0x72, 0x6b, 0x2f, 0x63, 0x6f, 0x6e, 0x6e,
	0x65, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x5f, 0x62, 0x61, 0x6c, 0x61, 0x6e, 0x63, 0x65, 0x2f, 0x64,
	0x6c, 0x62, 0x2f, 0x76, 0x33, 0x61, 0x6c, 0x70, 0x68, 0x61, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x33,
}

var (
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescOnce sync.Once
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescData = file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDesc
)

func file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescGZIP() []byte {
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescOnce.Do(func() {
		file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescData = protoimpl.X.CompressGZIP(file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescData)
	})
	return file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDescData
}

var file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_goTypes = []interface{}{
	(Dlb_FallbackPolicy)(0), // 0: envoy.extensions.network.connection_balance.dlb.v3alpha.Dlb.FallbackPolicy
	(*Dlb)(nil),             // 1: envoy.extensions.network.connection_balance.dlb.v3alpha.Dlb
}
var file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_depIdxs = []int32{
	0, // 0: envoy.extensions.network.connection_balance.dlb.v3alpha.Dlb.fallback_policy:type_name -> envoy.extensions.network.connection_balance.dlb.v3alpha.Dlb.FallbackPolicy
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_init() }
func file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_init() {
	if File_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*Dlb); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDesc,
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_goTypes,
		DependencyIndexes: file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_depIdxs,
		EnumInfos:         file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_enumTypes,
		MessageInfos:      file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_msgTypes,
	}.Build()
	File_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto = out.File
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_rawDesc = nil
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_goTypes = nil
	file_contrib_envoy_extensions_network_connection_balance_dlb_v3alpha_dlb_proto_depIdxs = nil
}
