//go:build !disable_pgv
// Code generated by protoc-gen-validate. DO NOT EDIT.
// source: envoy/service/redis_auth/v3/redis_external_auth.proto

package redis_authv3

import (
	"bytes"
	"errors"
	"fmt"
	"net"
	"net/mail"
	"net/url"
	"regexp"
	"sort"
	"strings"
	"time"
	"unicode/utf8"

	"google.golang.org/protobuf/types/known/anypb"
)

// ensure the imports are used
var (
	_ = bytes.MinRead
	_ = errors.New("")
	_ = fmt.Print
	_ = utf8.UTFMax
	_ = (*regexp.Regexp)(nil)
	_ = (*strings.Reader)(nil)
	_ = net.IPv4len
	_ = time.Duration(0)
	_ = (*url.URL)(nil)
	_ = (*mail.Address)(nil)
	_ = anypb.Any{}
	_ = sort.Sort
)

// Validate checks the field values on RedisProxyExternalAuthRequest with the
// rules defined in the proto definition for this message. If any rules are
// violated, the first error encountered is returned, or nil if there are no violations.
func (m *RedisProxyExternalAuthRequest) Validate() error {
	return m.validate(false)
}

// ValidateAll checks the field values on RedisProxyExternalAuthRequest with
// the rules defined in the proto definition for this message. If any rules
// are violated, the result is a list of violation errors wrapped in
// RedisProxyExternalAuthRequestMultiError, or nil if none found.
func (m *RedisProxyExternalAuthRequest) ValidateAll() error {
	return m.validate(true)
}

func (m *RedisProxyExternalAuthRequest) validate(all bool) error {
	if m == nil {
		return nil
	}

	var errors []error

	// no validation rules for Username

	// no validation rules for Password

	if len(errors) > 0 {
		return RedisProxyExternalAuthRequestMultiError(errors)
	}

	return nil
}

// RedisProxyExternalAuthRequestMultiError is an error wrapping multiple
// validation errors returned by RedisProxyExternalAuthRequest.ValidateAll()
// if the designated constraints aren't met.
type RedisProxyExternalAuthRequestMultiError []error

// Error returns a concatenation of all the error messages it wraps.
func (m RedisProxyExternalAuthRequestMultiError) Error() string {
	var msgs []string
	for _, err := range m {
		msgs = append(msgs, err.Error())
	}
	return strings.Join(msgs, "; ")
}

// AllErrors returns a list of validation violation errors.
func (m RedisProxyExternalAuthRequestMultiError) AllErrors() []error { return m }

// RedisProxyExternalAuthRequestValidationError is the validation error
// returned by RedisProxyExternalAuthRequest.Validate if the designated
// constraints aren't met.
type RedisProxyExternalAuthRequestValidationError struct {
	field  string
	reason string
	cause  error
	key    bool
}

// Field function returns field value.
func (e RedisProxyExternalAuthRequestValidationError) Field() string { return e.field }

// Reason function returns reason value.
func (e RedisProxyExternalAuthRequestValidationError) Reason() string { return e.reason }

// Cause function returns cause value.
func (e RedisProxyExternalAuthRequestValidationError) Cause() error { return e.cause }

// Key function returns key value.
func (e RedisProxyExternalAuthRequestValidationError) Key() bool { return e.key }

// ErrorName returns error name.
func (e RedisProxyExternalAuthRequestValidationError) ErrorName() string {
	return "RedisProxyExternalAuthRequestValidationError"
}

// Error satisfies the builtin error interface
func (e RedisProxyExternalAuthRequestValidationError) Error() string {
	cause := ""
	if e.cause != nil {
		cause = fmt.Sprintf(" | caused by: %v", e.cause)
	}

	key := ""
	if e.key {
		key = "key for "
	}

	return fmt.Sprintf(
		"invalid %sRedisProxyExternalAuthRequest.%s: %s%s",
		key,
		e.field,
		e.reason,
		cause)
}

var _ error = RedisProxyExternalAuthRequestValidationError{}

var _ interface {
	Field() string
	Reason() string
	Key() bool
	Cause() error
	ErrorName() string
} = RedisProxyExternalAuthRequestValidationError{}

// Validate checks the field values on RedisProxyExternalAuthResponse with the
// rules defined in the proto definition for this message. If any rules are
// violated, the first error encountered is returned, or nil if there are no violations.
func (m *RedisProxyExternalAuthResponse) Validate() error {
	return m.validate(false)
}

// ValidateAll checks the field values on RedisProxyExternalAuthResponse with
// the rules defined in the proto definition for this message. If any rules
// are violated, the result is a list of violation errors wrapped in
// RedisProxyExternalAuthResponseMultiError, or nil if none found.
func (m *RedisProxyExternalAuthResponse) ValidateAll() error {
	return m.validate(true)
}

func (m *RedisProxyExternalAuthResponse) validate(all bool) error {
	if m == nil {
		return nil
	}

	var errors []error

	if all {
		switch v := interface{}(m.GetStatus()).(type) {
		case interface{ ValidateAll() error }:
			if err := v.ValidateAll(); err != nil {
				errors = append(errors, RedisProxyExternalAuthResponseValidationError{
					field:  "Status",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		case interface{ Validate() error }:
			if err := v.Validate(); err != nil {
				errors = append(errors, RedisProxyExternalAuthResponseValidationError{
					field:  "Status",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		}
	} else if v, ok := interface{}(m.GetStatus()).(interface{ Validate() error }); ok {
		if err := v.Validate(); err != nil {
			return RedisProxyExternalAuthResponseValidationError{
				field:  "Status",
				reason: "embedded message failed validation",
				cause:  err,
			}
		}
	}

	if all {
		switch v := interface{}(m.GetExpiration()).(type) {
		case interface{ ValidateAll() error }:
			if err := v.ValidateAll(); err != nil {
				errors = append(errors, RedisProxyExternalAuthResponseValidationError{
					field:  "Expiration",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		case interface{ Validate() error }:
			if err := v.Validate(); err != nil {
				errors = append(errors, RedisProxyExternalAuthResponseValidationError{
					field:  "Expiration",
					reason: "embedded message failed validation",
					cause:  err,
				})
			}
		}
	} else if v, ok := interface{}(m.GetExpiration()).(interface{ Validate() error }); ok {
		if err := v.Validate(); err != nil {
			return RedisProxyExternalAuthResponseValidationError{
				field:  "Expiration",
				reason: "embedded message failed validation",
				cause:  err,
			}
		}
	}

	// no validation rules for Message

	if len(errors) > 0 {
		return RedisProxyExternalAuthResponseMultiError(errors)
	}

	return nil
}

// RedisProxyExternalAuthResponseMultiError is an error wrapping multiple
// validation errors returned by RedisProxyExternalAuthResponse.ValidateAll()
// if the designated constraints aren't met.
type RedisProxyExternalAuthResponseMultiError []error

// Error returns a concatenation of all the error messages it wraps.
func (m RedisProxyExternalAuthResponseMultiError) Error() string {
	var msgs []string
	for _, err := range m {
		msgs = append(msgs, err.Error())
	}
	return strings.Join(msgs, "; ")
}

// AllErrors returns a list of validation violation errors.
func (m RedisProxyExternalAuthResponseMultiError) AllErrors() []error { return m }

// RedisProxyExternalAuthResponseValidationError is the validation error
// returned by RedisProxyExternalAuthResponse.Validate if the designated
// constraints aren't met.
type RedisProxyExternalAuthResponseValidationError struct {
	field  string
	reason string
	cause  error
	key    bool
}

// Field function returns field value.
func (e RedisProxyExternalAuthResponseValidationError) Field() string { return e.field }

// Reason function returns reason value.
func (e RedisProxyExternalAuthResponseValidationError) Reason() string { return e.reason }

// Cause function returns cause value.
func (e RedisProxyExternalAuthResponseValidationError) Cause() error { return e.cause }

// Key function returns key value.
func (e RedisProxyExternalAuthResponseValidationError) Key() bool { return e.key }

// ErrorName returns error name.
func (e RedisProxyExternalAuthResponseValidationError) ErrorName() string {
	return "RedisProxyExternalAuthResponseValidationError"
}

// Error satisfies the builtin error interface
func (e RedisProxyExternalAuthResponseValidationError) Error() string {
	cause := ""
	if e.cause != nil {
		cause = fmt.Sprintf(" | caused by: %v", e.cause)
	}

	key := ""
	if e.key {
		key = "key for "
	}

	return fmt.Sprintf(
		"invalid %sRedisProxyExternalAuthResponse.%s: %s%s",
		key,
		e.field,
		e.reason,
		cause)
}

var _ error = RedisProxyExternalAuthResponseValidationError{}

var _ interface {
	Field() string
	Reason() string
	Key() bool
	Cause() error
	ErrorName() string
} = RedisProxyExternalAuthResponseValidationError{}
